@@ -14,7 +14,7 @@
 //! must be differenced after ordering the keys first, so that the set of changes
 //! produced can be made deterministic and thus expressible as a test expectation.
 //! 
-//! To these ends, the function [`assert_changes`] is also provided, taking two
+//! To these ends, the macro [`assert_changes!`] is also provided, taking two
 //! values of the same type along with an expected "change description" as
 //! returned by `foo.comparison(&bar)`. This function uses the
 //! [`pretty_assertions`](https://crates.io/crates/pretty_assertions) crate under
@@ -32,7 +32,7 @@
 //!    a. Create the initial state or dataset you intend to test and make a copy
 //!       of it.
 //!    b. Apply your operations and changes to this state.
-//!    c. Use [`assert_changes`] between the initial state and the resulting state
+//!    c. Use [`assert_changes!`] between the initial state and the resulting state
 //!       to assert that whatever happened is exactly what you expected to happen.
 //! 
 //! The main benefit of this approach over the usual method of "probing" the
@@ -139,10 +139,10 @@
 //! 
 //! ```
 //! # use comparable::*;
-//! assert_changes(&100, &100, Changed::Unchanged);
-//! assert_changes(&100, &200, Changed::Changed(I32Change(100, 200)));
-//! assert_changes(&true, &false, Changed::Changed(BoolChange(true, false)));
-//! assert_changes(
+//! assert_changes!(&100, &100, Changed::Unchanged);
+//! assert_changes!(&100, &200, Changed::Changed(I32Change(100, 200)));
+//! assert_changes!(&true, &false, Changed::Changed(BoolChange(true, false)));
+//! assert_changes!(
 //!     &"foo",
 //!     &"bar",
 //!     Changed::Changed(StringChange("foo".to_string(), "bar".to_string())),
@@ -172,12 +172,12 @@
 //! # use comparable::*;
 //! # use std::collections::HashSet;
 //! // Vectors
-//! assert_changes(
+//! assert_changes!(
 //!     &vec![1 as i32, 2],
 //!     &vec![1 as i32, 2, 3],
 //!     Changed::Changed(vec![VecChange::Added(2, 3)]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &vec![1 as i32, 3],
 //!     &vec![1 as i32, 2, 3],
 //!     Changed::Changed(vec![
@@ -185,7 +185,7 @@
 //!         VecChange::Added(2, 3),
 //!     ]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &vec![1 as i32, 2, 3],
 //!     &vec![1 as i32, 3],
 //!     Changed::Changed(vec![
@@ -193,29 +193,29 @@
 //!         VecChange::Removed(2, 3),
 //!     ]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &vec![1 as i32, 2, 3],
 //!     &vec![1 as i32, 4, 3],
 //!     Changed::Changed(vec![VecChange::Changed(1, I32Change(2, 4))]),
 //! );
 //! 
 //! // Sets
-//! assert_changes(
+//! assert_changes!(
 //!     &HashSet::from(vec![1 as i32, 2].into_iter().collect()),
 //!     &HashSet::from(vec![1 as i32, 2, 3].into_iter().collect()),
 //!     Changed::Changed(vec![SetChange::Added(3)]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &HashSet::from(vec![1 as i32, 3].into_iter().collect()),
 //!     &HashSet::from(vec![1 as i32, 2, 3].into_iter().collect()),
 //!     Changed::Changed(vec![SetChange::Added(2)]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &HashSet::from(vec![1 as i32, 2, 3].into_iter().collect()),
 //!     &HashSet::from(vec![1 as i32, 3].into_iter().collect()),
 //!     Changed::Changed(vec![SetChange::Removed(2)]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &HashSet::from(vec![1 as i32, 2, 3].into_iter().collect()),
 //!     &HashSet::from(vec![1 as i32, 4, 3].into_iter().collect()),
 //!     Changed::Changed(vec![SetChange::Added(4), SetChange::Removed(2)]),
@@ -273,27 +273,27 @@
 //! # use comparable::*;
 //! # use std::collections::HashMap;
 //! // HashMaps
-//! assert_changes(
+//! assert_changes!(
 //!     &HashMap::from(vec![(0, 1 as i32), (1, 2)].into_iter().collect()),
 //!     &HashMap::from(vec![(0, 1 as i32), (1, 2), (2, 3)].into_iter().collect()),
 //!     Changed::Changed(vec![MapChange::Added(2, 3)]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &HashMap::from(vec![(0, 1 as i32), (1, 2), (2, 3)].into_iter().collect()),
 //!     &HashMap::from(vec![(0, 1 as i32), (1, 2)].into_iter().collect()),
 //!     Changed::Changed(vec![MapChange::Removed(2)]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &HashMap::from(vec![(0, 1 as i32), (2, 3)].into_iter().collect()),
 //!     &HashMap::from(vec![(0, 1 as i32), (1, 2), (2, 3)].into_iter().collect()),
 //!     Changed::Changed(vec![MapChange::Added(1, 2)]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &HashMap::from(vec![(0, 1 as i32), (1, 2), (2, 3)].into_iter().collect()),
 //!     &HashMap::from(vec![(0, 1 as i32), (2, 3)].into_iter().collect()),
 //!     Changed::Changed(vec![MapChange::Removed(1)]),
 //! );
-//! assert_changes(
+//! assert_changes!(
 //!     &HashMap::from(vec![(0, 1 as i32), (1, 2), (2, 3)].into_iter().collect()),
 //!     &HashMap::from(vec![(0, 1 as i32), (1, 4), (2, 3)].into_iter().collect()),
 //!     Changed::Changed(vec![MapChange::Changed(1, I32Change(2, 4))]),
@@ -611,7 +611,7 @@
 //! struct with multiple fields:
 //! 
 //! ```ignore
-//! assert_changes(
+//! assert_changes!(
 //!     &initial_foo, &later_foo,
 //!     Changed::Changed(vec![
 //!         MyStructChange::Bar(...),
@@ -920,6 +920,15 @@ pub use crate::string::*;
 
 pub use crate::types::{Changed, Comparable};
 
+/// Assert that two values of a type have changed in the way described.
+#[macro_export]
+macro_rules! assert_changes {
+    ($left:expr, $right:expr, $expected:expr$(,)?) => {{
+        use comparable::Comparable;
+        assert_eq!($expected, $left.comparison(&$right));
+    }};
+}
+
 /// Assert that two values of a type have either not changed, or they have
 /// changed only to the extent described by the give change set. This allows
 /// tests to confirm that what they expected to see happened, and anything
@@ -930,12 +939,41 @@ pub use crate::types::{Changed, Comparable};
 /// ```ignore
 /// pretty_assertions::assert_eq!(expected, left.comparison(right))
 /// ```
-pub fn assert_changes<T: Comparable>(
-    left: &T,
-    right: &T,
-    expected: Changed<<T as Comparable>::Change>,
-) {
-    pretty_assertions::assert_eq!(expected, left.comparison(right))
+#[macro_export]
+macro_rules! pretty_assert_changes {
+    ($left:expr, $right:expr, $expected:expr$(,)?) => {{
+        use comparable::Comparable;
+        pretty_assertions::assert_eq!($expected, $left.comparison(&$right));
+    }};
+}
+
+/// Assert that two values of a type have changed in the way described,
+/// stopping at the first failure if this occurs in a proptest block.
+#[macro_export]
+macro_rules! prop_assert_changes {
+    ($left:expr, $right:expr, $expected:expr$(,)?) => {{
+        use comparable::Comparable;
+        proptest::prop_assert_eq!($expected, $left.comparison(&$right));
+    }};
+}
+
+/// Assert that two values of a type have changed in the way described,
+/// stopping at the first failure if this occurs in a proptest block.
+#[macro_export]
+macro_rules! prop_pretty_assert_changes {
+    ($left:expr, $right:expr, $expected:expr$(,)?) => {{
+        use comparable::Comparable;
+        let changes = $left.comparison(&$right);
+        if $expected != changes {
+            return Err(proptest::test_runner::TestCaseError::fail(format!(
+                "prop_assert_changes! failed: `(left == right)`\
+                 \n\
+                 \n{}\
+                 \n",
+                pretty_assertions::Comparison::new(&$expected, &changes)
+            )));
+        }
+    }};
 }
 
 // Re-export #[derive(Comparable)].
